<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;  // Import Mail facade
use Illuminate\Support\Str;
use App\Mail\OTPMail;  // Import the OTPMail Mailable class

class OtpController extends Controller
{
    public function showVerifyForm()
    {
        return view('auth.otp-verify'); // Ensure this view exists
    }
    /**
     * Generate and send OTP to the user's email and store registration data in session.
     */
    public function sendOtp(Request $request)
    {
        // Validate the incoming registration data
        $userData = $request->validate([
            'full_name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'state_country' => 'required|string|max:255',
            'department' => 'required|string|max:255',
            'contact_number' => 'nullable|string|max:255',
            'password' => 'required|confirmed|min:8',
        ]);

        // Store the registration data in the session temporarily
        session()->put('userData', $userData);
        // session([
        //     'registration_data' => $request->only('full_name', 'email', 'state_country', 'industry', 'phone', 'password')
        // ]);

        // Generate a 6-digit OTP
        $otp = Str::random(6);

        // Send the OTP via email
        Mail::to($request->email)->send(new OTPMail($otp));

        // Store OTP in the session temporarily
        session()->put(['otp' => $otp]);

        // Redirect to OTP verification page
        return redirect()->route('otp.verify.form')->with('status', 'OTP sent to your email. Please check your inbox.');
    }

   
}
