<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;
use App\Models\QrCode;
use Illuminate\View\View;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     */
    public function create(): View
    {
        return view('auth.register'); // Make sure your register view has fields for full_name, state_country, etc.
    }
    /**
     * Display the registration completion view.
     */
    
    /**
     * Handle an incoming registration request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request): RedirectResponse
    {
        // Retrieve the registration data from the session
        $data = session()->get('userData');

        $request->validate([
            'otp' => 'required',
        ]);

        // Check if the OTP matches the one in the session
        if ($request->otp != session()->get('otp')) {
            return back()->withErrors(['otp' => 'Invalid OTP. Please try again.']);
        }

        // Create the user in the database
        $user = User::create([
            'full_name' => $data['full_name'],
            'email' => $data['email'],
            'state_country' => $data['state_country'],
            'department' => $data['department'],
            'contact_number' => $data['contact_number'],
            'password' => Hash::make($data['password']),
        ]);

        // Generate a QR code for the user
        // $qrCode = new QrCode();
        // $qrCodePath = $qrCode->generateQrCode($user); // Pass the user to the method
        // QrCode::create([
        //     'user_id' => $user->id,
        //     'qr_code_path' => $qrCodePath,
        // ]);

        QrCode::generateForUser($user);

        // Clear the session data
        session()->forget('userData');
        session()->forget('otp');

        // Log the user in
        auth()->login($user);

        // Redirect to the dashboard
        return redirect()->route('dashboard')->with('status', 'Registration complete!');
    }
}
