<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Certificate;
use Illuminate\Http\Request;
use App\Models\CertificateShare;
use Illuminate\Support\Facades\Auth;

class CertificateController extends Controller
{
    

     /**
     * Store a new certificate.
     */
    public function store(Request $request)
    {
        // dd($request->all());
        
        $validated = $request->validate([
            'title' => 'required|string|max:255',
            'training_center' => 'required|string|max:255',
            'issued_date' => 'required|date',
            'expiration_date' => 'nullable|date',
            'certificate_file1' => 'nullable|file|mimes:jpg,jpeg,png,pdf|max:2048',
            'certificate_file2' => 'nullable|file|mimes:jpg,jpeg,png,pdf|max:2048',
            'certificate_file' => 'nullable|file|mimes:jpg,jpeg,png,pdf|max:2048',
            'driverlicense_file' => 'nullable|file|mimes:jpg,jpeg,png,pdf|max:2048',
            // 'notify' => 'nullable',
            'instructor_name' => 'nullable|string|max:255',
            'instructor_phone' => 'nullable|string|max:255',
            'certificate_number' => 'nullable|string|max:255',
        ]);

        // Handle file upload
        if ($request->hasFile('certificate_file1')) {            
            $validated['certificate_file'] = $request->file('certificate_file1')->store('certificates', 'public');
        }
        if ($request->hasFile('certificate_file2')) {            
            $validated['certificate_file'] = $request->file('certificate_file2')->store('certificates', 'public');
        }
        if ($request->hasFile('driverlicense_file')) {
            $validated['driverlicense_file'] = $request->file('driverlicense_file')->store('driverlicenses', 'public');
        }

        // dd($validated);

        $validated['user_id'] = Auth::id();

        $certificate = Certificate::create($validated);
        $certificate->notify = $request->has('notify') ? true : false;
        $certificate->save();

        return redirect()->back()->with('success', 'Certificate added successfully.');
    }

    /**
     * Delete a certificate.
     */
    public function destroy(Certificate $certificate)
    {
        if ($certificate->user_id !== auth()->id()) {
            abort(403);
        }

        // Delete the certificate file if exists
        if ($certificate->certificate_file) {
            \Storage::disk('public')->delete($certificate->certificate_file);
        }

        $certificate->delete();

        return redirect()->back()->with('success', 'Certificate deleted successfully!');
    }

    public function search(Request $request)
    {
        $sharedCertificates = CertificateShare::with('certificate')
            ->whereHas('certificate', fn($query) => $query->where('shared', true))
            ->when($request->email, fn($query) => $query->where('recipient_email', 'LIKE', "%{$request->email}%"))
            ->when($request->id, fn($query) => $query->where('certificate_id', $request->id))
            ->get();

        return view('sharedcertificates', compact('sharedCertificates'));
    }

    public function unshare($id)
    {
        $certificate = Certificate::findOrFail($id);

        if ($certificate->user_id !== Auth::id()) {
            abort(403, 'Unauthorized action.');
        }

        $certificate->update(['shared' => false]);

        return redirect()->route('certificates.shared')->with('success', 'Certificate unshared successfully.');
    }

    public function searchCertificates(Request $request)
    {
        $query = CertificateShare::query();

        // Apply filters based on the search inputs
        if ($request->filled('name')) {
            $query->whereHas('user', function ($userQuery) use ($request) {
                $userQuery->where('full_name', 'like', '%' . $request->name . '%');
            });
        }

        if ($request->filled('email')) {
            $query->whereHas('user', function ($userQuery) use ($request) {
                $userQuery->where('email', 'like', '%' . $request->email . '%');
            });
        }

        if ($request->filled('id')) {
            $query->where('id', $request->id);
        }

        $employeeCertificates = $query->with(['certificate', 'sharedBy','user'])->get();
        

        // Return the view with the filtered certificates
        return view('employeecertificates', compact('employeeCertificates'));
    }
}
