<?php

namespace App\Http\Controllers;

use App\Models\Certificate;
use Illuminate\Http\Request;
use App\Models\CertificateShare;
use Illuminate\Support\Facades\Auth;

class CertificateShareController extends Controller
{
    public function store(Request $request)
    {
        $request->validate([
            'certificate_id' => 'required|exists:certificates,id',
            'recipient_email' => 'required|email',
            'message' => 'nullable|string|max:500',
        ]);

        $certificate_ids = $request->certificate_id;
        $ids = explode(',', $certificate_ids);
        // $count = count($ids);
        foreach($ids as $id)
        {
            // Check if the certificate belongs to the authenticated user
            $certificate = Certificate::where('id', $id)
            ->where('user_id', Auth::id())
            ->first();

            // Update or create the certificate share entry
            CertificateShare::updateOrCreate(
                [
                    'certificate_id' => $certificate->id,
                    'recipient_email' => $request->recipient_email, // Uniqueness condition
                ],
                [
                    'user_id' => Auth::id(), // If exists, update these columns
                    'message' => $request->message,
                ]
            );

            // Mark the certificate as shared
            $certificate->update(['shared' => true]);
        }

        return redirect()->back()->with('success', 'Certificate shared successfully!');
    }
}
