<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Review;
use App\Models\Certificate;
use Illuminate\Http\Request;
use App\Models\CertificateShare;

class ViewController extends Controller
{
    public function showdashboard()
    {
        $summaryCards = [
            ['title' => 'Active User', 'count' => 874, 'trend' => 4.85],
            ['title' => 'Total User', 'count' => 1432, 'trend' => 2.19],
            ['title' => 'Viewer Not Registered', 'count' => 231, 'trend' => -0.76],
            ['title' => 'New Registration', 'count' => 200, 'trend' => 0.15],
        ];
    
        $rightCards = [
            ['title' => 'Offline User', 'count' => 500, 'icon' => 'user-icon.svg'],
            ['title' => 'Most users are from', 'count' => 'United States', 'icon' => 'flag-icon.svg'],
            ['title' => 'Total Registered Emails', 'count' => 2000, 'icon' => 'email-icon.png'],
            ['title' => 'Total Certificates', 'count' => 4900, 'icon' => 'certify-icon.png'],
        ];
    
        $chartData = [
            'labels' => ['12th Sep', '13th Sep', '14th Sep', '15th Sep', '16th Sep', '17th Sep', '18th Sep'],
            'datasets' => [
                [
                    'label' => '15th Sep',
                    'data' => [50, 70, 60, 76, 65, 80, 55],
                    'backgroundColor' => 'rgba(79, 70, 229, 0.2)',
                    'borderColor' => '#4f46e5',
                    'borderWidth' => 2,
                ],
            ],
        ]; 
        
    
        return view('dashboard', compact('summaryCards', 'rightCards', 'chartData'));   
        
    }

    public function showmycertificates()
    {
        $certificates = Certificate::where('user_id', auth()->user()->id)->get(); // Fetch user's certificates
        return view('mycertificates', ['certificates' => $certificates]);
    }
    /**
     * Display a listing of the reviews.
     */
    public function showseemyreviews()
    {
        $reviews = Review::with('user')->paginate(10);
        $averageRating = Review::avg('rating');
        $totalReviews = Review::count();

        // Calculate rating distribution
        $ratingDistribution = Review::selectRaw('rating, COUNT(*) as count')
            ->groupBy('rating')
            ->pluck('count', 'rating')
            ->toArray();

        return view('seemyreviews', compact('reviews', 'averageRating', 'totalReviews', 'ratingDistribution'));
    }

    public function showsharedcertificates()
    {
        $sharedCertificates = CertificateShare::with(['certificate', 'user'])
            ->where('user_id', auth()->user()->id)
            ->get();

        return view('sharedcertificates', compact('sharedCertificates'));
    }

    public function showemployeecertificates()
    {
        $employeeCertificates = CertificateShare::where('recipient_email', auth()->user()->email)
        ->with(['certificate', 'sharedBy'])
        ->get();

        return view('employeecertificates', compact('employeeCertificates'));
    }

    // admin views
    public function showcertificatestoverify()
    {
        $certificates = Certificate::with('user')->where('verification_status', 'Pending')->get();
        return view('certificatestoverify', compact('certificates'));
    }
    public function searchCertificatestoVerify(Request $request)
    {
        $query = User::query();

        // Apply search filters if provided
        if ($request->filled('name')) {
            $query->where('full_name', 'like', '%' . $request->name . '%');
        }
        if ($request->filled('email')) {
            $query->where('email', 'like', '%' . $request->email . '%');
        }
        if ($request->filled('id')) {
            $query->where('id', $request->id);
        }

        // Fetch users with certificate counts
        $users = $query->with('certificates')->paginate(10);
        $certificates = Certificate::with('user')->where('verification_status', 'Pending')->get();
        return view('certificatestoverify', compact('certificates'));
    }
    /**
     * Display the GiggyCode users with their details.
     */
    public function showGiggyCodeUsers()
    {
        $users = User::with('certificates')->paginate(10);
        // Fetch users with certificate counts        
        $verifiedCertificates = [];
        foreach ($users as $user) {
            $verifiedCertificates[$user->id] = Certificate::where('verification_status', 'Verified')->where('user_id', $user->id)->get();
            // $verifiedCertificates[] = count($verifiedCertificates[$user->id]);
        }
        return view('viewgiggycodeusers', compact('users','verifiedCertificates'));
    }
    /**
     * Display the GiggyCode users with their details.
     */
    public function searchGiggyCodeUsers(Request $request)
    {
        $query = User::query();

        // Apply search filters if provided
        if ($request->filled('name')) {
            $query->where('full_name', 'like', '%' . $request->name . '%');
        }
        if ($request->filled('email')) {
            $query->where('email', 'like', '%' . $request->email . '%');
        }
        if ($request->filled('id')) {
            $query->where('id', $request->id);
        }

        // Fetch users with certificate counts
        $users = $query->with('certificates')->paginate(10);
        $verifiedCertificates = [];
        foreach ($users as $user) {
            $verifiedCertificates[$user->id] = Certificate::where('verification_status', 'Verified')->where('user_id', $user->id)->get();
            // $verifiedCertificates[] = count($verifiedCertificates[$user->id]);
        }
         
        return view('viewgiggycodeusers', compact('users','verifiedCertificates'));

    }
    
    public function verifiedCertificates()
    {
        $certificates = Certificate::with('user')->where('verification_status', 'Verified')->paginate(10);
        return view('verifiedcertificates', compact('certificates'));
    }

    public function searchVerifiedCertificates(Request $request)
    {
        $query = User::query();

        // Apply search filters if provided
        if ($request->filled('name')) {
            $query->where('full_name', 'like', '%' . $request->name . '%');
        }
        if ($request->filled('email')) {
            $query->where('email', 'like', '%' . $request->email . '%');
        }
        if ($request->filled('id')) {
            $query->where('id', $request->id);
        }

        // Fetch users with certificate counts
        $users = $query->with('certificates')->get();
        $certificates = [];
        foreach($users as $user){
            $certificates[$user->id] = Certificate::with('user')->where('verification_status', 'Verified')->where('user_id', $user->id)->get();
        }
        
        return view('verifiedcertificates', compact('certificates'));
    }

    public function verifyCertificate(Request $request)
    {
        $certificate = Certificate::find($request->certificate_id);
        $certificate->verification_status = $request->verification_status;

        $certificate->save();
        return response()->json(['success' => true, 'message' => 'Certificate Status updated successfully.']);
    }

}
