<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Storage;
use SimpleSoftwareIO\QrCode\Facades\QrCode as QrCodeGenerator;

class QrCode extends Model
{
    protected $fillable = ['user_id', 'qr_code_path', 'user_link', 'guest_link'];

    /**
     * Generate and store a QR Code for the given user.
     */
    public static function generateForUser($user)
    {
        // Define links
        $data = [
            'guest_link' => route('profile.guest', ['id' => $user->id]),
            'user_link' => route('profile.user', ['id' => $user->id]),
        ];

        // Generate the QR code
        

        // Encode data as JSON
        $jsonData = json_encode($data['user_link']);

        // Generate QR Code and store it in the public storage
        $qrCodePath = 'qr_codes/' . uniqid() . '.png';
        Storage::disk('public')->put($qrCodePath, QrCodeGenerator::format('png')->size(300)->generate($jsonData));

        // Return the QR code URL or path
        $qrCodeUrl = Storage::url($qrCodePath);

        // Save to database
        return self::create([
            'user_id' => $user->id,
            'qr_code_path' => $qrCodePath,
            'user_link' => $data['user_link'],
            'guest_link' => $data['guest_link'],
        ]);
    }
}
