@extends('layouts.app')

@push('styles')
<style>
    .star {
        color: gray;
        transition: color 0.2s ease-in-out;
        cursor: pointer;
        font-size: 2rem;
    }

    .star.active {
        color: gold;
    }

    .carousel-item img {
        max-height: 300px;
        object-fit: contain;
        margin: auto;
    }
</style>
@endpush

@section('content')
<div class="container">
    <h2>{{ $viewUser->full_name }}'s Shared Certificates</h2>

    @if ($viewUser->certificates->isNotEmpty())
        <!-- Carousel for Certificates -->
        <div id="certificatesCarousel" class="carousel slide" data-bs-ride="carousel">
            <div class="carousel-inner">
                @foreach ($viewUser->certificates as $index => $certificate)
                    <div class="carousel-item {{ $index === 0 ? 'active' : '' }}">
                        <img src="{{ asset('storage/' . $certificate->certificate_file) }}" class="d-block w-100" alt="Certificate">
                        <div class="carousel-caption d-none d-md-block">
                            <h5>{{ $certificate->title }}</h5>
                            <p><strong>Training Center:</strong> {{ $certificate->training_center }}</p>
                            <p><strong>Issued:</strong> {{ $certificate->issued_date }}</p>
                            <p><strong>Expires:</strong> {{ $certificate->expiration_date ?? 'N/A' }}</p>
                        </div>
                    </div>
                @endforeach
            </div>
            <button class="carousel-control-prev" type="button" data-bs-target="#certificatesCarousel" data-bs-slide="prev">
                <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                <span class="visually-hidden">Previous</span>
            </button>
            <button class="carousel-control-next" type="button" data-bs-target="#certificatesCarousel" data-bs-slide="next">
                <span class="carousel-control-next-icon" aria-hidden="true"></span>
                <span class="visually-hidden">Next</span>
            </button>
        </div>

        <!-- Add Rating for User -->
        <div class="rating-section mt-4">
            <h4>Rate {{ $viewUser->full_name }}</h4>
            <form method="POST" action="{{ route('users.rate', $viewUser->id) }}" id="ratingForm">
                @csrf
                <div class="star-rating d-flex align-items-center">
                    @for ($i = 1; $i <= 5; $i++)
                        <span class="star" data-value="{{ $i }}">&#9733;</span>
                    @endfor
                </div>
                <input type="hidden" name="rating" id="ratingInput" required>
                <label for="">Leave A Comment </label>
                <textarea name="review" id="review" cols="30" rows="10"></textarea>
                <button type="submit" class="btn btn-primary mt-3">Submit</button>
            </form>
        </div>
    @else
        <p>No certificates shared by this user.</p>
    @endif
</div>
@endsection

@push('scripts')
<script>
    document.addEventListener('DOMContentLoaded', function () {
        const stars = document.querySelectorAll('.star');
        const ratingInput = document.getElementById('ratingInput');

        stars.forEach(star => {
            star.addEventListener('click', function () {
                const rating = this.getAttribute('data-value');
                ratingInput.value = rating;

                // Highlight all stars up to the clicked one
                stars.forEach(s => {
                    s.classList.toggle('active', s.getAttribute('data-value') <= rating);
                });
            });
        });
    });
</script>
@endpush
