@extends('layouts.app')

@section('title', 'Certificates to Verify')

@push('styles')
<style>
    /* Include your custom CSS styles here */
    .table-header th:first-child {
        border-top-left-radius: 20px;
    }

    .table-header th:last-child {
        border-top-right-radius: 10px;
    }

    .table-container {
        width: 100%;
        padding: 20px;
        border-radius: 10px;
        margin-top: 20px;
        overflow-x: auto;
    }

    .table-header {
        background-color: #1a0dab;
        color: white;
        font-weight: bold;
        text-align: left;
        border-radius: 10px 10px 0 0;
    }

    .table-header th {
        padding: 15px;
        font-size: 16px;
    }

    .table-row {
        background-color: #d9dff4;
        font-size: 14px;
    }

    .table-row td {
        padding: 10px;
        border-bottom: 2px solid #f3f4f6;
    }

    .table-row:last-child td {
        border-bottom: none;
    }
    
    .expired {
        color: red;
        font-weight: bold;
    }

    .note {
        background-color: #ffffff;
        color: #1a0dab;
        border: 1px solid #1a0dab;
        padding: 5px 10px;
        border-radius: 5px;
        font-size: 0.8rem
    }

    .note:hover {
        background-color: #190775;
        color: #d9dff4;
    }

    .btn-unshare {
        background-color: #1a0dab;
        color: white;
        border: none;
        padding: 5px 15px;
        border-radius: 5px;
    }

    .btn-unshare:hover {
        background-color: white;
        color: #190775;
    }

    .btn-close1 {
        width: 49%;
        color: #1f1f8b;
        background-color: white;
        border: 2px solid;
    }

    .btn-close1:hover {
        color: white;
        background-color: #1f1f8b;
    }

    input.form-control {
        padding: 1.5rem .75rem;
        background-color: #001BA119;
        color: black;
    }

    input.form-control::placeholder {
        color: black;
    }

    .search {
        width: 100%;
        padding: 1.5rem;
        background-color: #1a0dab;
    }

    .search:hover {
        background-color: white;
        color: #190775;
    }

    .william {
        padding: 10px;
        border: 1px solid;
        font-size: 24px;
        border-radius: 13px;
        color: white;
        background-color: #190776;
    }

    /* modal Styling */
    .modal-content {
        border-radius: 10px;
        padding: 20px;
    }

    .modal-header {
        border-bottom: none;
        padding-bottom: 0;
        display: flex;
        justify-content: space-between;
        align-items: flex-start;
    }

    .modal-title {
        font-size: 20px;
        font-weight: bold;
        margin: 0;
    }

    .modal-date {
        font-size: 14px;
        color: #666;
        margin-top: 4px;
    }

    .modal-body {
        margin-top: 15px;
    }

    textarea {
        width: 100%;
        height: 200px;
        border: 1px solid #ddd;
        border-radius: 5px;
        padding: 10px;
        background-color: #f9f9f9;
        font-size: 14px;
        color: #555;
        resize: none;
    }

    .btn-close {
        margin-top: -10px;
    }
</style>
@endpush

@section('content')

<div class="container my-5">
    

    <div class="row align-items-center w-100 mb-3">
        <div class="col-lg-8 col-12 text-lg-start text-center mb-2 mb-lg-0">
            <h4 class="text-black fw-bold">Certificates to Verify</h4>
        </div>
    </div>

    <div class="row mb-3 g-3">
        <form method="GET" action="{{ route('unverified.certificate.search') }}" class="row">
            <div class="col-md-3">
                <input type="text" class="form-control" name="name" placeholder="Full Name" value="{{ request('name') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="email" placeholder="Email Address" value="{{ request('email') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="id" placeholder="ID 10,001" value="{{ request('user_id') }}">
            </div>
            <div class="col-md-3">
                <button class="btn btn-primary search" type="submit">Search</button>
            </div>
        </form>
    </div>

    <div class="table-container">
        <table style="width: 100%; border-spacing: 0 15px;">
            <thead class="table-header py-5">
                <tr>
                    <th>User ID</th>
                    <th>User Name</th>
                    <th>Notes</th>
                    <th>Instructor</th>
                    <th>Country/State</th>
                    <th>Department</th>
                    <th>Action</th>
                    <th>Certificate</th>
                </tr>
            </thead>
            <tbody>
                @forelse ($certificates as $certificate)
                <tr class="table-row">
                    <td>ID {{ $certificate->user->id }}</td>
                    <td>{{ $certificate->user->full_name }}</td>
                    <td>
                        <button class="btn btn-primary note" data-bs-toggle="modal" data-bs-target="#noteModal-{{ $certificate->id }}">
                            Type your Note
                        </button>
                    </td>
                    <td>{{ $certificate->instructor_name }}</td>
                    <td>{{ $certificate->user->state_country }}</td>
                    <td>{{ $certificate->user->department }}</td>
                    
                    <td>
                        <div class="dropdown">
                            <button class="btn-unshare dropdown-toggle" type="button" id="statusDropdown-{{ $certificate->id }}" data-bs-toggle="dropdown">
                                {{ $certificate->verification_status }}
                            </button>
                            <ul class="dropdown-menu" aria-labelledby="statusDropdown-{{ $certificate->id }}">
                                <li>
                                    <a class="dropdown-item" href="javascript:void(0)" 
                                        onclick="updateVerificationStatus({{ $certificate->id }}, 'Verified', this.closest('.dropdown').querySelector('.dropdown-toggle'))">
                                        Verified
                                    </a>
                                </li>
                                <li>
                                    <a class="dropdown-item" href="javascript:void(0)" 
                                        onclick="updateVerificationStatus({{ $certificate->id }}, 'Pending', this.closest('.dropdown').querySelector('.dropdown-toggle'))">
                                        Pending
                                    </a>
                                </li>
                            </ul>
                        </div>
                    </td>
                    <td>
                        <div class="certificate-img position-relative" style="background-image: url('{{ asset("storage/" . $certificate->certificate_file) }}'); 
                        background-size: cover;background-repeat: no-repeat;">
                            {{-- <img src="{{ asset('storage/' . $certificate->certificate_file) }}" alt="Certificate"
                                class="img-fluid rounded"> --}}
                                <button class="btn btn-secondary" style="background:#6c757d91;margin: auto;align-items: center;width: 100%;" data-bs-toggle="modal"
                                    data-bs-target="#certificateModal-{{ $certificate->id }}">View Certificate</button>
                            {{-- <div class="overlay position-absolute top-50 start-50 translate-middle text-center text-white fw-bold">
                                
                            </div> --}}
                        </div>
                    </td>
                </tr>
                <!-- Notes Modal -->
<div class="modal fade" id="noteModal-{{ $certificate->id }}" tabindex="-1" aria-labelledby="notesModalLabel"
    aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Notes for {{ $certificate->user->full_name }}</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <textarea>{{ $certificate->notes }}</textarea>
            </div>
        </div>
    </div>
</div>

<!-- Certificate Modal -->
<div class="modal fade" id="certificateModal-{{ $certificate->id }}" tabindex="-1"
    aria-labelledby="certificateModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <img src="{{ asset('storage/' . $certificate->certificate_file) }}" alt="Certificate"
                    class="img-fluid" />
            </div>
        </div>
    </div>
</div>
               
                @empty
                <tr>
                    <td colspan="8" class="text-center">No certificate to Verify.</td>
                </tr>
                @endforelse
            </tbody>
        </table>
    </div>
</div>
@endsection



@push('scripts')
<script>
    function updateVerificationStatus(certificateId, newStatus, dropdownElement) {
    // Define the URL for the request
    const url = "{{ route('certificate.update.status') }}";

    // Send AJAX request to the server
    fetch(url, {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
            "X-CSRF-TOKEN": "{{ csrf_token() }}" // Pass CSRF token
        },
        body: JSON.stringify({
            certificate_id: certificateId,
            verification_status: newStatus
        })
    })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                // Update the dropdown with the new status
                dropdownElement.innerHTML = newStatus;

                // Display a success message
                alert("Verification status updated successfully.");
            } else {
                // Display an error message if something went wrong
                alert("Failed to update verification status.");
            }
        })
        .catch(error => {
            console.error("Error updating verification status:", error);
            alert("An error occurred. Please try again.");
        });
}


    </script> 
@endpush
