@extends('layouts.app')

@section('title', 'Employee Certificates')

@push('styles')
<style>
    /* Base styles */
    .container {
        margin: 1.5rem auto;
    }

    /* Form and Input styles */
    .form-control {
        padding: 1.5rem 0.75rem;
        background-color: rgba(0, 27, 161, 0.1);
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: all 0.3s ease;
    }

    .form-control:focus {
        border-color: #190775;
        box-shadow: 0 0 0 0.2rem rgba(25, 7, 117, 0.25);
    }

    /* Button styles */
    .btn {
        font-family: 'Arial', sans-serif;
        transition: all 0.3s ease;
    }

    .btn-primary {
        background-color: #190775;
        border-color: #190775;
        color: white;
        width: 100%;
        padding: 1.5rem;
    }

    .btn-primary:hover {
        background-color: #150659;
        border-color: #150659;
    }

    .btn-outline-primary {
        color: #190775;
        border-color: #190775;
    }

    .btn-outline-primary:hover {
        background-color: #190775;
        color: white;
    }

    .btn-outline-dark {
        color: #000;
        border-color: transparent;
    }

    .btn-outline-dark:hover {
        color: white;
        background-color: #000;
    }

    /* Certificate card styles */
    .certificate-card {
        background-color: #e7eefe;
        display: flex;
        justify-content: space-between;
        flex-wrap: wrap;
        align-items: center;
        padding: 1rem;
        margin-bottom: 1rem;
        border-radius: 0.5rem;
    }

    .certificate-img {
        height: 80px;
        width: 140px;
        position: relative;
        overflow: hidden;
    }

    .certificate-img img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .certificate-img .overlay {
        padding: 5px 10px;
        border-radius: 5px;
        opacity: 0;
        transition: opacity 0.3s ease;
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
    }

    .certificate-img:hover .overlay {
        opacity: 1;
    }

    /* Text styles */
    .text-danger {
        font-weight: bold;
    }

    .text-success {
        font-size: 0.9rem;
    }

    .user-name {
        color: #190775;
        font-weight: bold;
        font-size: 1.2rem;
    }

    .user-id {
        font-size: 0.9rem;
        color: #555;
    }

    /* Media queries */
    @media (max-width: 768px) {
        .col-md-3 {
            margin-bottom: 1rem;
        }

        .certificate-card {
            flex-direction: column;
            align-items: flex-start;
        }

        .certificate-img {
            margin-top: 1rem;
            height: 100px;
            width: 200px;
        }
    }
</style>
@endpush

@section('content')
<div class="container my-4">
    <div class="row align-items-center w-100 mb-3">
        <div class="col-lg-8 col-12 text-lg-start text-center mb-2 mb-lg-0">
            <h4 class="text-black fw-bold">Employee Certificates</h4>
        </div>
    </div>

    <!-- Search Filters -->
    <div class="row mb-3 g-3">
        <form method="GET" action="{{ route('employee-certificates.search') }}" class="row">
            <div class="col-md-3">
                <input type="text" class="form-control" name="name" placeholder="Full Name"
                    value="{{ request('name') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="email" placeholder="Email Address"
                    value="{{ request('email') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="id" placeholder="ID" value="{{ request('id') }}">
            </div>
            <div class="col-md-3">
                <button class="btn btn-primary search" type="submit">Search</button>
            </div>
        </form>
    </div>

    @forelse ($employeeCertificates as $employeeCertificate)
        <div class="certificate-card border rounded p-3 mb-3 d-flex align-items-center flex-wrap">
            <div class="me-3">
                <p class="mb-0 fw-bold">Employee Name</p>
                <p class="mb-0">{{ $employeeCertificate->user->full_name }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Certificate Title:</p>
                <p class="mb-0">{{ $employeeCertificate->certificate->title }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Training Center:</p>
                <p class="mb-0">{{ $employeeCertificate->certificate->training_center }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Issued Date:</p>
                <p class="mb-0">
                    {{ \Carbon\Carbon::parse($employeeCertificate->certificate->issued_date)->format('d M, Y') }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Expiry Date:</p>
                <p class="mb-0 text-danger">
                    {{ $employeeCertificate->certificate->expiration_date ? \Carbon\Carbon::parse($employeeCertificate->certificate->expiration_date)->format('d M, Y') : 'N/A' }}
                </p>
            </div>
            <div class="me-3">
                <button class="btn btn-outline-dark btn-lg">
                    <i class="bi bi-printer"></i>
                </button>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Status :</p>
                <p class="mb-0 text-black">{{ $employeeCertificate->certificate->shared ? 'Aproved' : 'Not Aproved' }}
                </p>
            </div>
            <div class="certificate-img position-relative">
                <img src="{{ asset('storage/' . $employeeCertificate->certificate->certificate_file) }}"
                    alt="Certificate" class="img-fluid rounded">
                <div class="overlay position-absolute top-50 start-50 translate-middle text-center text-white fw-bold">
                    <button class="btn btn-secondary" data-bs-toggle="modal"
                        data-bs-target="#certificateModal-{{ $employeeCertificate->certificate->id }}">
                        View Certificate
                    </button>
                </div>
            </div>
        </div>

        <!-- Modal for Viewing Certificate -->
        <div class="modal fade" id="certificateModal-{{ $employeeCertificate->certificate->id }}" tabindex="-1"
            aria-labelledby="certificateModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered">
                <div class="modal-content">
                    <div class="modal-header">
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <img src="{{ asset('storage/' . $employeeCertificate->certificate->certificate_file) }}"
                            alt="Certificate" class="img-fluid">
                    </div>
                </div>
            </div>
        </div>
    @empty
        <p>No certificates shared with you.</p>
    @endforelse
</div>
@endsection
