@extends('layouts.app')

@section('title', 'Show My Certificates')

@push('styles')
    <style>
        .btn {
            font-family: 'Arial', sans-serif;
            /* Uniform font family */
        }

        .btn-outline-primary {
            color: #190775 !important;
            border-color: #190775 !important;
        }

        .btn-outline-primary:hover {
            background-color: #190775 !important;
            color: white !important;
        }

        .btn-primary {
            background-color: #190775;
            border-color: #190775;
        }

        .btn-primary:hover {
            background-color: #150659;
            border-color: #150659;
        }

        .certificate-card {
            background-color: #e7eefe;
            display: flex;
            justify-content: space-between;
            flex-wrap: wrap;
            align-items: center;
        }

        .certificate-img {
            height: 80px;
            width: 140px;
            position: relative;
            overflow: hidden;
        }

        .certificate-img img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }

        .certificate-img .overlay {
            padding: 5px 10px;
            border-radius: 5px;
            opacity: 0;
            transition: opacity 0.3s ease;
        }

        .certificate-img:hover .overlay {
            opacity: 1;
        }

        .text-danger {
            font-weight: bold;
        }

        .text-success {
            font-size: 0.9rem;
        }

        .btn-outline-primary {
            color: #0d6efd;
            border-color: #0d6efd;
        }

        .btn-outline-primary:hover {
            color: #fff;
            background-color: #0d6efd;
        }

        .btn-outline-dark {
            color: #000;
            border-color: transparent;
        }

        .btn-outline-dark:hover {
            color: #fff;
            background-color: #000;
        }

        /* Modal Stylling */

        .modal-header {
            border-bottom: none;
        }

        .modal-content {
            border-radius: 8px;
        }

        .modal-title {
            font-weight: bold;
        }

        .modal-footer {
            border-top: none;
            justify-content: center;
        }

        /* Your custom CSS for the card design */
        .icon-box {
            border: 2px solid black;
            padding: 20px;
            border-radius: 8px;
            text-align: center;
            cursor: pointer;
            margin-bottom: 20px;
            color: #1f1f8b;
            width: 100%;
            /* purple color for the text */
        }

        .icons {
            font-size: 30px;
            /* Adjust icon size */
        }

        /* Make the file inputs hidden, so they don't affect layout */
        .file-input {
            display: none;
        }

        /* Hover effect for cards */
        .icon-box:hover {
            background-color: #f7f7f7;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        /* Card content styling */
        .card-title {
            font-size: 16px;
            margin-top: 10px;
        }


        .form-label {
            font-weight: bold;
        }

        .form-check-label {
            color: #1f1f8b;
        }

        .notify-text {
            color: red;
            font-size: 0.875rem;
        }

        .btn-close {
            color: #1f1f8b;
        }

        .save-btn {
            width: 49%;
            color: #1f1f8b;
            background-color: white;
            border: 2px solid;
        }

        .save-btn:hover {
            color: white;
            background-color: #1f1f8b;
        }

        #hiddenSection {
            max-height: 0;
            /* Hidden by default */
            overflow: hidden;
            transition: max-height 0.4s ease-out, opacity 0.4s ease-out;
            opacity: 0;
        }

        #hiddenSection.visible {
            max-height: 500px;
            /* Adjust to a value large enough to fit the content */
            opacity: 1;
        }

        #share-txt-area {
            width: 100%;
            height: 250px;
        }

        /* Qr Code stylling */
        .qr-image {
            border-radius: 8px;
            padding: 10px;
            width: 60%;
        }

        .user-name {
            color: #190775;
            font-weight: bold;
            font-size: 1.2rem;
        }

        .user-id {
            font-size: 0.9rem;
            color: #555;
        }

        .btn-share,
        .btn-print {
            width: 100px;
            font-size: 0.9rem;
        }

        @media (max-width: 768px) {
            .certificate-card {
                flex-direction: column;
                align-items: flex-start;
            }

            .certificate-img {
                margin-top: 10px;
                height: 100px;
                width: 200px;
            }
        }
    </style>
@endpush
@section('content')
    <!-- main content section -->
    <div class="container my-4">
        <div class="row align-items-center w-100 mb-3">
            <!-- Text Section -->
            <div class="col-lg-8 col-12 text-lg-start text-center mb-2 mb-lg-0">
                <h4 class="text-black fw-bold">See My Certificates ?</h4>
            </div>
            <!-- Buttons Section -->
            <div class="col-lg-4 col-12 d-flex justify-content-center justify-content-lg-end gap-2">
                <button class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#QrShareModal">
                    <img src="images/qr-icon.svg" class="icons"> Shared
                </button>
                <button class="btn btn-outline-primary" data-bs-toggle="modal" onclick="setShareModal('{{ $qrCode->user_link ?? '' }}')">
                    <i class="bi bi-share-fill"></i> Share
                </button>
                
                <button class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#addCertificateModal">
                    <i class="bi bi-plus"></i> Add
                </button>
            </div>
        </div>

        <!-- Certificate Cards Section -->
        @if(!empty($certificates) && count($certificates) > 0)
            
        @foreach ($certificates as $certificate)
        <div class="certificate-card border rounded p-3 mb-3 d-flex align-items-center flex-wrap">
            <div class="me-3">
                <input type="checkbox" class="form-check-input certificate-checkbox" data-id="{{ $certificate->id }}">
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Certificate Title:</p>
                <p class="mb-0">{{ $certificate->title }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Training Center:</p>
                <p class="mb-0">{{ $certificate->training_center }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Issued Date:</p>
                <p class="mb-0">{{ $certificate->issued_date }}</p>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Expiry Date:</p>
                <p class="mb-0 text-danger">
                    {{ $certificate->expiration_date ? $certificate->expiration_date : 'N/A' }}
                </p>
            </div>
            <div class="me-3">
                <button class="btn btn-outline-dark btn-lg" data-bs-toggle="modal" data-bs-target="#deleteModal"
                    onclick="setDeleteModal('{{ $certificate->id }}')">
                    <i class="bi bi-trash"></i>
                </button>
            </div>
            <div class="me-3">
                <button class="btn btn-outline-dark btn-lg">
                    <i class="bi bi-printer"></i>
                </button>
            </div>
            <div class="me-3">
                <p class="mb-0 fw-bold">Status :</p>
                <p class="mb-0 text-black">{{ $certificate->status ?? 'Pending' }}</p>
            </div>
            <div class="certificate-img position-relative">
                <img src="{{ asset('storage/' . $certificate->certificate_file) }}" alt="Certificate"
                    class="img-fluid rounded">
                <div class="overlay position-absolute top-50 start-50 translate-middle text-center text-white fw-bold">
                    <button class="btn btn-secondary" data-bs-toggle="modal" data-bs-target="#certificateModal"
                        onclick="viewCertificate('{{ asset('storage/' . $certificate->certificate_file) }}')">
                        View Certificate
                    </button>
                </div>
            </div>
        </div>
    @endforeach
    
        @else
            <p class="text-center fw-bold">No certificates available at the moment.</p>
        @endif
    </div>


@endsection
@section('modal')

    <!-- Modals -->
    @include('modals.add-certificate')
    @include('modals.share-certificate')
    @include('modals.qr-modal')
    @include('modals.delete-certificate')
    @include('modals.view-certificate')
@endsection

@push('scripts')
    <script>
        function toggleHiddenSection() {
            const checkbox = document.getElementById('verifyCertification'); // Get the checkbox element
            const hiddenSection = document.getElementById('hiddenSection'); // Get the section to show/hide

            if (checkbox.checked) {
                hiddenSection.classList.add('visible');
            } else {
                hiddenSection.classList.remove('visible');
            }
        }

        function viewCertificate(fileUrl) {
            const modalBody = document.querySelector('#certificateModal .modal-body');
            modalBody.innerHTML = `<img src="${fileUrl}" class="img-fluid" alt="Certificate">`;
        }

        function setDeleteModal(certificateId) {
            const deleteForm = document.querySelector('#deleteCertificateForm');
            deleteForm.action = `/certificates/${certificateId}`;
        }
    </script>
@endpush
