@push('styles')
<style>
    h1 {
        color: #190775;
        font-size: 26px;
        font-family: 'Arial', sans-serif;
    }

    p,
    .btn {
        font-family: 'Arial', sans-serif;
    }

    .btn-outline-primary {
        color: #190775;
        border-color: #190775;
    }

    .btn-outline-primary:hover {
        background-color: #190775;
        color: white;
    }

    .btn-primary {
        background-color: #190775;
        border-color: #190775;
    }

    .btn-primary:hover {
        background-color: #150659;
        border-color: #150659;
    }

    .btn-group .active {
        background-color: #190775;
        border-color: #190775;
    }

    .custom-card {
        background-color: transparent;
        border: 1px solid #190775;
    }

    .custom-card-active {
        border: none;
        border-radius: 10px;
        background-color: #190775;
        color: #fff;
    }

    .custom-card h5,
    .custom-card h6 {
        font-size: 1.5rem;
        font-weight: bold;
        color: black;
    }

    .custom-card p {
        margin: 0;
        color: #737588;
    }

    .custom-card img {
        display: inline-block;
        margin-right: 15px;
    }

    .icon {
        width: 50px;
        height: 50px;
        object-fit: contain;
    }

    .btn-group {
        width: 30%;
    }

    .card.shadow-sm {
        border-radius: 12px;
    }

    .navbar-toggler-white .navbar-toggler-icon {
        background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='white' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }

    .navbar-toggler-white {
        border: 1px solid white;
    }

    @media (max-width:768px) {
        .custom-tab-nav {
            flex-direction: column;
        }

        .btn-group {
            width: 80%;
        }

        .custom-card {
            margin-bottom: 15px;
        }
    }
</style>
@endpush

@section('content')


<div class="container mt-4">
    <div class="d-flex justify-content-between align-items-center mb-4 custom-tab-nav">
        <h4 class="fw-bold">Analytics</h4>
        <div class="btn-group">
            @foreach (['Day', 'Week', 'Month', 'Year'] as $timeframe)
            <button class="btn btn-outline-primary {{ $loop->first ? 'active' : '' }}">{{ $timeframe }}</button>
            @endforeach
        </div>
    </div>

    <!-- Top Cards -->
    <div class="row mb-4">
        @foreach ($summaryCards as $card)
        <div class="col-md-3">
            <div class="card {{ $loop->first ? 'custom-card-active' : 'custom-card' }} shadow-sm text-white p-3">
                <h5 class="mb-2">{{ $card['count'] }}</h5>
                <p class="mb-1">{{ $card['title'] }}</p>
                <span class="{{ $card['trend'] > 0 ? 'text-success' : 'text-danger' }}">
                    {{ $card['trend'] > 0 ? '↑' : '↓' }} {{ abs($card['trend']) }}%
                </span>
            </div>
        </div>
        @endforeach
    </div>

    <div class="row">
        <div class="col-md-8">
            <div class="card shadow-sm p-4">
                <canvas id="analyticsGraph" class="py-3"></canvas>
            </div>
        </div>
        <div class="col-md-4">
            @foreach ($rightCards as $card)
            <div class="card custom-card mb-3 shadow-sm p-3 d-flex align-items-center flex-row">
                <img src="{{ asset('images/' . $card['icon']) }}" alt="{{ $card['title'] }}" class="icon me-3">
                <div>
                    <h6 class="mb-1">{{ $card['count'] }}</h6>
                    <p class="mb-0">{{ $card['title'] }}</p>
                </div>
            </div>
            @endforeach
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    const ctx = document.getElementById('analyticsGraph').getContext('2d');
    const chartData = @json($chartData);

    const analyticsGraph = new Chart(ctx, {
        type: 'line',
        data: chartData,
        options: {
            responsive: true,
            plugins: {
                tooltip: {
                    mode: 'index',
                    intersect: false,
                },
                legend: {
                    display: false,
                },
            },
            scales: {
                x: {
                    grid: {
                        drawBorder: false,
                    },
                },
                y: {
                    grid: {
                        drawBorder: false,
                    },
                    beginAtZero: true,
                },
            },
        },
    });
</script>
@endpush
