@push('styles')
    <style>
        h1 {
            color: #190775;
            /* Primary heading color */
            font-size: 26px;
            /* Slightly larger font size to match design */
            font-family: 'Arial', sans-serif;
            /* Use a clean sans-serif font */
        }

        p,
        .btn {
            font-family: 'Arial', sans-serif;
            /* Uniform font family */
        }

        .btn-outline-primary {
            color: #190775;
            border-color: #190775;
        }

        .btn-outline-primary:hover {
            background-color: #190775;
            color: white;
        }

        .btn-primary {
            background-color: #190775;
            border-color: #190775;
        }

        .btn-primary:hover {
            background-color: #150659;
            border-color: #150659;
        }

        .william {
            padding: 10px;
            border: 1px solid;
            font-size: 24px;
            border-radius: 13px;
            color: white;
            background-color: #190776;
            font-size: 24px;
        }

        .navbar-toggler-white .navbar-toggler-icon {
            background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='white' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
        }

        .navbar-toggler-white {
            border: 1px solid white;
        }

        /* Modal Stylling */

        .modal-header {
            border-bottom: none;
        }

        .modal-content {
            border-radius: 8px;
        }

        .modal-title {
            font-weight: bold;
        }

        .modal-footer {
            border-top: none;
            justify-content: center;
        }

        /* Your custom CSS for the card design */
        .icon-box {
            border: 2px solid black;
            padding: 20px;
            border-radius: 8px;
            text-align: center;
            cursor: pointer;
            margin-bottom: 20px;
            color: #1f1f8b;
            width: 100%;
            /* purple color for the text */
        }

        .icons {
            font-size: 30px;
            /* Adjust icon size */
        }

        /* Make the file inputs hidden, so they don't affect layout */
        .file-input {
            display: none;
        }

        /* Hover effect for cards */
        .icon-box:hover {
            background-color: #f7f7f7;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        /* Card content styling */
        .card-title {
            font-size: 16px;
            margin-top: 10px;
        }


        .form-label {
            font-weight: bold;
        }

        .form-check-label {
            color: #1f1f8b;
        }

        .notify-text {
            color: red;
            font-size: 0.875rem;
        }

        .btn-close {
            color: #1f1f8b;
        }

        .save-btn {
            width: 48%;
            color: #1f1f8b;
            background-color: white;
            border: 2px solid;
        }

        .save-btn:hover {
            color: white;
            background-color: #1f1f8b;
        }

        #hiddenSection {
            max-height: 0;
            /* Hidden by default */
            overflow: hidden;
            transition: max-height 0.4s ease-out, opacity 0.4s ease-out;
            opacity: 0;
        }

        #hiddenSection.visible {
            max-height: 500px;
            /* Adjust to a value large enough to fit the content */
            opacity: 1;
        }

        /* Qr Code stylling */
        .qr-image {
            border-radius: 8px;
            padding: 10px;
            width: 60%;
        }

        .user-name {
            color: #190775;
            font-weight: bold;
            font-size: 1.2rem;
        }

        .user-id {
            font-size: 0.9rem;
            color: #555;
        }

        .btn-share,
        .btn-print {
            width: 100px;
            font-size: 0.9rem;
        }

        #share-txt-area {
            width: 100%;
            height: 250px;
        }

        /* modal for edit-profile stylling */
        .upload-picture {
            display: flex;
            justify-content: center;
            align-items: center;
            margin-bottom: 20px;
        }

        .upload-picture img {
            border-radius: 50%;
            width: 100px;
            height: 100px;
            object-fit: cover;
        }

        .upload-picture input[type="file"] {
            display: none;
        }

        .upload-placeholder {
            position: relative;
            width: 100px;
            height: 100px;
            border-radius: 50%;
            border: 2px dashed #ccc;
            display: flex;
            justify-content: center;
            align-items: center;
            cursor: pointer;
        }

        .upload-placeholder:after {
            content: 'Upload Picture';
            position: absolute;
            font-size: 12px;
            color: #666;
            bottom: -20px;
            text-align: center;
        }
    </style>
@endpush

@section('content')
    <!-- Main Content Section  -->
    <div class="container py-5">
        <div class="row align-items-center">
            <!-- Profile Section -->
            <div class="col-12 col-lg-8 d-flex align-items-center mb-3 mb-lg-0">
                <img src="{{ $user->profile_picture ? asset('storage/' . $user->profile_picture) : asset('images/default-profile.png') }}" 
                alt="User Image" 
                class="rounded-circle me-3"
                style="width: 80px; height: 80px;">           
                <div>
                    @if ($user->role == 'Supervisor')
                    <p class="mb-1 text-uppercase fw-bold text-muted" style="font-size: 12px;">Supervisor</p>                        
                    @endif
                    <div class="d-flex align-items-center">
                        <h1 class="mb-0 william">Hello,
                            {{ $user->full_name }}</h1>
                        
                    </div>
                </div>
            </div>

            <!-- Buttons Section -->
            <div class="col-12 col-lg-4 text-lg-end d-flex d-lg-inline justify-content-center gap-2">
                <button class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#QrShareModal">
                    <img src="images/qr-icon.svg" class="icons"> Shared
                </button>                
                <button class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#editProfileModal">
                    <i class="bi bi-pencil"></i> Edit Profile
                </button>
            </div>
        </div>

        <!-- Additional Content -->
        <div class="row mt-4">
            <div class="col-md-12">
                <div class="card shadow-sm border-0 rounded p-4">
                    <h2 class="mb-4" style="color: #190775">Basic Information</h2>
                    <div class="row">
                         <!-- User Details -->
                         <div class="col-md-12">
                            <ul class="list-group list-group-flush">
                                <li class="list-group-item">
                                    <strong>Email: </strong> <span class="text-secondary">{{ $user->email }}</span>
                                </li>
                                <li class="list-group-item">
                                    <strong>State/Country: </strong> <span class="text-secondary">{{ $user->state_country }}</span>
                                </li>
                                <li class="list-group-item">
                                    <strong>Department: </strong> <span class="text-secondary">{{ $user->department }}</span>
                                </li>
                                <li class="list-group-item">
                                    <strong>Designation: </strong> <span class="text-secondary">{{ $user->designation }}</span>
                                </li>
                                <li class="list-group-item">
                                    <strong>Phone: </strong> <span class="text-secondary">{{ $user->contact_number ?? 'N/A' }}</span>
                                </li>
                            </ul>
                        </div>
                       
                    </div>                   
                </div>
            </div>
            
        </div>
        
    </div>
@endsection
@section('modal')
    {{-- @include('modals.add-certificate') --}}
    {{-- @include('modals.share-certificate') --}}
    @include('modals.qr-modal')
    @include('modals.edit-profile')
@endsection
@push('scripts')
    <!-- Custom JavaScript -->
    <script>
        function previewImage(event) {
            const input = event.target;
            const preview = document.getElementById('profilePicturePreview');

            if (input.files && input.files[0]) {
                const reader = new FileReader();

                reader.onload = function(e) {
                    preview.src = e.target.result;
                };

                reader.readAsDataURL(input.files[0]);
            }
        }

        function toggleHiddenSection() {
            const checkbox = document.getElementById('verifyCertification'); // Get the checkbox element
            const hiddenSection = document.getElementById('hiddenSection'); // Get the section to show/hide

            if (checkbox.checked) {
                hiddenSection.classList.add('visible');
            } else {
                hiddenSection.classList.remove('visible');
            }
        }
    </script>
@endpush