@extends('layouts.app')

@section('title', 'See My Reviews')

@push('styles')
<style>
    .btn-outline-primary {
        color: #190775 !important;
        border-color: #190775 !important;
    }

    .btn-outline-primary:hover {
        background-color: #190775 !important;
        color: white !important;
    }

    .dropdown-toggle {
        background: #190775;
        color: #fff;
    }

    .progress-bar {
        background-color: #190775;
    }

    .bi-star-fill {
        color: #F3B428;
    }

    .reviews-section {
        background-color: #f8f9fa;
        border-radius: 10px;
        padding: 20px;
    }

    .rating-box {
        font-size: 3rem;
        background: #f0f0f0;
        color: #3a3ab8;
        width: 80px;
        height: 80px;
        display: flex;
        justify-content: center;
        align-items: center;
        border-radius: 10px;
        font-weight: bold;
    }

    .star-row {
        display: flex;
        align-items: center;
        margin-bottom: 15px;
    }

    .progress {
        flex: 1;
        height: 8px;
        margin: 0 15px;
        background-color: #f0f0f0;
        border-radius: 5px;
        overflow: hidden;
    }

    .review-count {
        font-size: 0.9rem;
        color: #6c757d;
    }

    .card {
        box-shadow: 0px 3px 6px rgba(0, 0, 0, 0.1);
    }
</style>
@endpush

@section('content')
<div class="container py-5">
    <!-- Heading and Filter -->
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h5 class="mb-0 text-black fs-3 fw-bold">See My Reviews</h5>
        <div class="dropdown">
            <button class="btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown" aria-expanded="false">
                Filter Reviews
            </button>
            <ul class="dropdown-menu">
                @for ($i = 5; $i >= 1; $i--)
                    <li>
                        <a class="dropdown-item" href="{{ route('reviews.filter', ['rating' => $i]) }}">
                            <i class="bi bi-star-fill text-warning"></i> {{ $i }} Stars
                        </a>
                    </li>
                @endfor
            </ul>
        </div>
    </div>

    <!-- Review Summary -->
    <div class="card reviews-section">
        <div class="d-flex flex-wrap align-items-center mb-3">
            <div class="rating-box me-3 mb-2">
                {{ number_format($averageRating, 1) ?? '0.0' }}
            </div>
            <div>
                @for ($i = 1; $i <= 5; $i++)
                    <i class="bi bi-star-fill {{ $i <= floor($averageRating) ? 'text-warning' : 'text-secondary' }}"></i>
                @endfor
                <p class="mb-2 fs-3"><strong>From {{ $totalReviews }} reviews</strong></p>
            </div>
        </div>

        <!-- Rating Distribution -->
        <div class="row">
            @foreach ($ratingDistribution as $stars => $count)
                <div class="col-md-6">
                    <div class="star-row">
                        <div class="stars">
                            <i class="bi bi-star-fill text-warning"></i> <strong>{{ $stars }}</strong>
                        </div>
                        <div class="progress">
                            <div class="progress-bar" style="width: {{ $count ? ($count / $totalReviews) * 100 : 0 }}%;"></div>
                        </div>
                        <div class="review-count">{{ $count }} reviews</div>
                    </div>
                </div>
            @endforeach
        </div>
    </div>

    <!-- Individual Reviews -->
    <div class="mt-4">
        @if ($reviews->isNotEmpty())
            @foreach ($reviews as $review)
                <div class="card mb-3">
                    <div class="card-body">
                        <h5 class="card-title">{{ $review->title }}</h5>
                        <p class="card-text">{{ $review->content }}</p>
                        <p class="card-text">
                            <small class="text-muted">
                                Rated {{ $review->stars }} stars on {{ $review->created_at->format('d M, Y') }}
                            </small>
                        </p>
                    </div>
                </div>
            @endforeach
        @else
            <p class="text-center">No reviews available.</p>
        @endif

        <!-- Pagination -->
        <div class="d-flex justify-content-center mt-3">
            {{ $reviews->links() }}
        </div>
    </div>
</div>
@endsection
