@extends('layouts.app')

@section('title', 'Shared Certificates')

@push('styles')
    <style>
        .table-header th:first-child {
            border-top-left-radius: 20px;
        }

        .table-header th:last-child {
            border-top-right-radius: 10px;
        }

        .table-container {
            width: 100%;

            padding: 20px;
            border-radius: 10px;
            margin-top: 20px;
            overflow-x: auto;

        }

        .table-header {
            background-color: #1a0dab;
            color: white;
            font-weight: bold;
            text-align: left;
            border-radius: 10px 10px 0 0;
        }

        .table-header th {
            padding: 15px;
            font-size: 16px;
        }

        .table-row {
            background-color: #d9dff4;
            font-size: 14px;
        }

        .table-row td {
            padding: 15px;
            border-bottom: 2px solid #f3f4f6;
        }

        .table-row:last-child td {
            border-bottom: none;
        }

        .expired {
            color: red;
            font-weight: bold;
        }

        .note {
            background-color: #ffffff;
            color: #1a0dab;
            border: 1px solid #1a0dab;
            padding: 5px 10px;
            border-radius: 5px;
            font-size: 0.8rem
        }

        .note:hover {
            background-color: #190775;
            color: #d9dff4;
        }

        .btn-unshare {
            background-color: #1a0dab;
            color: white;
            border: none;
            padding: 5px 15px;
            border-radius: 5px;
        }

        .btn-unshare:hover {
            background-color: white;
            color: #190775;
        }

        .btn-close1 {
            width: 49%;
            color: #1f1f8b;
            background-color: white;
            border: 2px solid;
        }

        .btn-close1:hover {
            color: white;
            background-color: #1f1f8b;
        }



        input.form-control {
            padding: 1.5rem .75rem;
            background-color: #001BA119;
            color: black;
        }

        input.form-control::placeholder {
            color: black;
        }

        .search {
            width: 100%;
            padding: 1.5rem;
            background-color: #1a0dab;
        }

        .search:hover {
            background-color: white;
            color: #190775;
        }

        /* modal Stylling */
        .modal-content {
            border-radius: 10px;
            padding: 20px;
        }

        .modal-header {
            border-bottom: none;
            padding-bottom: 0;
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
        }

        .modal-title {
            font-size: 20px;
            font-weight: bold;
            margin: 0;
        }

        .modal-date {
            font-size: 14px;
            color: #666;
            margin-top: 4px;
        }

        .modal-body {
            margin-top: 15px;
        }

        textarea {
            width: 100%;
            height: 200px;
            border: 1px solid #ddd;
            border-radius: 5px;
            padding: 10px;
            background-color: #f9f9f9;
            font-size: 14px;
            color: #555;
            resize: none;
        }

        .btn-close {
            margin-top: -10px;
        }
    </style>
@endpush

@section('content')
    <div class="container my-5">
        <h1 class="mb-4">Shared Certificates</h1>

        <!-- Search Filters -->
        <div class="row mb-3 g-3">
            <form method="GET" action="{{ route('certificates.shared.search') }}" class="row">
                <div class="col-md-3">
                    <input type="text" class="form-control" name="name" placeholder="Full Name"
                        value="{{ request('name') }}">
                </div>
                <div class="col-md-3">
                    <input type="text" class="form-control" name="email" placeholder="Email Address"
                        value="{{ request('email') }}">
                </div>
                <div class="col-md-3">
                    <input type="text" class="form-control" name="id" placeholder="ID" value="{{ request('id') }}">
                </div>
                <div class="col-md-3">
                    <button class="btn btn-primary search" type="submit">Search</button>
                </div>
            </form>
        </div>

        <!-- Certificates Table -->
        <div class="table-container">
            <table style="width: 100%; border-spacing: 0;">
                <thead class="table-header">
                    <tr>
                        <th>Supervisor Email</th>
                        <th>Certificates</th>
                        <th>Expiry Date</th>
                        <th>Notes</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($sharedCertificates as $share)
                        <tr class="table-row">
                            <td>{{ $share->recipient_email }}</td>
                            <td>{{ optional($share->certificate)->title ?? 'N/A' }}</td>
                            <td class="{{ optional($share->certificate)->isExpired() ? 'expired' : '' }}">
                                {{ optional($share->certificate)->expiration_date ?? 'N/A' }}
                            </td>
                            <td>
                                <button class="btn btn-primary note" data-bs-toggle="modal"
                                    data-bs-target="#noteModal-{{ $share->id }}">Type your Note</button>
                                <!-- Note Modal -->
                                <div class="modal fade" id="noteModal-{{ $share->id }}" tabindex="-1"
                                    aria-labelledby="noteModalLabel-{{ $share->id }}" aria-hidden="true">
                                    <div class="modal-dialog modal-dialog-centered">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <div>
                                                    <h5 class="modal-title" id="noteModalLabel-{{ $share->id }}">
                                                        Notes</h5>
                                                    <div class="modal-date">
                                                        {{ optional($share->certificate)->expiration_date ?? 'N/A' }}</div>
                                                </div>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                    aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                <textarea>{{ $share->message }}</textarea>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                            <td>
                                <form method="POST" action="{{ route('certificates.shared.unshare', $share->id) }}">
                                    @csrf
                                    @method('DELETE')
                                    <button type="submit" class="btn btn-unshare">Unshare</button>
                                </form>
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="5" class="text-center">No shared certificates found.</td>
                        </tr>
                    @endforelse
                </tbody>
                
            </table>
        </div>        
    </div>
@endsection
