@extends('layouts.app')

@section('title', 'View GiggyCode Users')

@push('styles')
<style>
    .btn {
        font-family: 'Arial', sans-serif;
    }

    .btn-outline-primary {
        color: #190775 !important;
        border-color: #190775 !important;
    }

    .btn-outline-primary:hover {
        background-color: #190775 !important;
        color: white !important;
    }

    .btn-primary {
        background-color: #190775;
        border-color: #190775;
    }

    .btn-primary:hover {
        background-color: #150659;
        border-color: #150659;
    }

    input.form-control {
        padding: 1.5rem .75rem;
        background-color: #001BA119;
        color: black;
    }

    input.form-control::placeholder {
        color: black;
    }
    
    .search {
        width: 100%;
        padding: 1.5rem;
        background-color: #1a0dab;
    }

    .search:hover {
        background-color: white;
        color: #190775;
    }

    .certificate-card {
        background-color: #e7eefe;
        display: flex;
        justify-content: space-between;
        flex-wrap: wrap;
        align-items: center;
    }

    .certificate-img {
        height: 80px;
        width: 140px;
        position: relative;
        overflow: hidden;
    }

    .certificate-img img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .certificate-img .overlay {
        padding: 5px 10px;
        border-radius: 5px;
        opacity: 0;
        transition: opacity 0.3s ease;
    }

    .certificate-img:hover .overlay {
        opacity: 1;
    }

    .text-danger {
        font-weight: bold;
    }
    textarea {
        width: 100%;
        height: 200px;
        border: 1px solid #ddd;
        border-radius: 5px;
        padding: 10px;
        background-color: #f9f9f9;
        font-size: 14px;
        color: #555;
        resize: none;
    }

    .text-success {
        font-size: 0.9rem;
    }

    .note {
        background-color: #ffffff;
        color: #1a0dab;
        border: 1px solid #1a0dab;
        padding: 5px 10px;
        border-radius: 5px;
        font-size: 0.8rem
    }

    .note:hover {
        background-color: #190775;
        color: #d9dff4;
    }

    .modal-content {
        border-radius: 10px;
        padding: 20px;
    }

    @media (max-width: 768px) {
        .certificate-card {
            flex-direction: column;
            align-items: flex-start;
        }

        .certificate-img {
            margin-top: 10px;
            height: 100px;
            width: 200px;
        }
    }
</style>
@endpush

@section('content')
<div class="container my-4">
    <div class="row align-items-center">
        <div class="col-12 col-lg-8 d-flex align-items-center mb-3 mb-lg-0">
            <img src="{{ $user->profile_picture ? asset('storage/' . $user->profile_picture) : asset('images/default-profile.png') }}" 
            alt="User Image" 
            class="rounded-circle me-3"
            style="width: 80px; height: 80px;">           
            <div>
                <p class="mb-1 text-uppercase fw-bold text-muted" style="font-size: 12px;">Admin</p>                        
               
                <div class="d-flex align-items-center">
                    <h1 class="mb-0 william">Hello,
                        {{ $user->full_name }}</h1>
                    
                </div>
            </div>
        </div>
        <div class="col-12 col-lg-4 text-lg-end d-flex d-lg-inline justify-content-center gap-2">            
            <button class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#editProfileModal">
                <i class="bi bi-pencil"></i> Edit Profile
            </button>
        </div>
    </div>

    <div class="row mt-4">
        <p class="mb-5 fw-bold" style="font-size: 20px;">View GiggyCode Users</p>
    </div>

    <div class="row mb-3 g-3">
        <form method="GET" action="{{ route('users.search') }}" class="row">
            <div class="col-md-3">
                <input type="text" class="form-control" name="name" placeholder="Full Name" value="{{ request('name') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="email" placeholder="Email Address" value="{{ request('email') }}">
            </div>
            <div class="col-md-3">
                <input type="text" class="form-control" name="id" placeholder="ID 10,001" value="{{ request('user_id') }}">
            </div>
            <div class="col-md-3">
                <button class="btn btn-primary search" type="submit">Search</button>
            </div>
        </form>
    </div>

    @forelse ($users as $user)
    <!-- Certificate Card -->
    <div class="certificate-card border rounded p-3 mb-3 d-flex align-items-center flex-wrap">
        <div class="me-3">
            <p class="mb-0 fw-bold">User ID</p>
            <p class="mb-0">ID {{ $user->id }}</p>
        </div>

        <div class="me-3">
            <p class="mb-0 fw-bold">Name</p>
            <p class="mb-0">{{ $user->full_name }}</p>
        </div>
        <div class="me-3">
            <p class="mb-0 fw-bold">Email Address</p>
            <p class="mb-0 ">{{ $user->email }}</p>
        </div>
        <div class="me-3">
            <p class="mb-0 fw-bold">Total Certificates</p>
            <p class="mb-0 ">{{ $user->certificates->count() }}</p>
        </div>
        <div class="me-3">
            <p class="mb-0 fw-bold">Verified Certificates</p>
            <p class="mb-0 ">{{ count($verifiedCertificates[$user->id]) }}</p>
        </div>
        
        <div class="me-3">
            <p class="mb-0 fw-bold">Notes</p>
            <p class="mb-0"><button class="btn btn-primary note" data-bs-toggle="modal"
                    data-bs-target="#noteModal-{{ $user->id }}">Type your Note</button></p>
        </div>
        
        <div class="me-3">
            <p class="mb-0 fw-bold">Role</p>
            <li class="list-unstyled">
                <a class="text-decoration-none text-black dropdown-toggle" href="#" id="roleDropdown-{{ $user->id }}"
                    role="button" data-bs-toggle="dropdown" aria-expanded="false">{{ $user->role }}
                </a>
                <ul class="dropdown-menu" aria-labelledby="roleDropdown-{{ $user->id }}">
                    <li><a class="dropdown-item" href="javascript:void(0)" onclick="updateRole({{ $user->id }}, 'Supervisor')">Supervisor</a></li>
                    <li><a class="dropdown-item" href="javascript:void(0)" onclick="updateRole({{ $user->id }}, 'Employee')">Employee</a></li>
                </ul>
            </li>
        </div>
        

        <div class="me-3">
            <p class="mb-0 fw-bold">Action</p>
            <li class="list-unstyled">
                <a class="text-decoration-none text-black dropdown-toggle" href="#" id="actionDropdown-{{ $user->id }}"
                    role="button" data-bs-toggle="dropdown" aria-expanded="false">{{ $user->status }}
                </a>
                <ul class="dropdown-menu" aria-labelledby="actionDropdown-{{ $user->id }}">
                    <li><a class="dropdown-item" href="javascript:void(0)" onclick="updateStatus({{ $user->id }}, 'Active')">Activate</a></li>
                    <li><a class="dropdown-item" href="javascript:void(0)" onclick="updateStatus({{ $user->id }}, 'Deactivated')">Deactivate</a></li>
                </ul>
            </li>
        </div>
        
        
    </div>
    <!-- Note Modal -->
<div class="modal fade" id="noteModal-{{ $user->id }}" tabindex="-1" aria-labelledby="noteModalLabel-{{ $user->id }}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="noteModalLabel-{{ $user->id }}">Notes for {{ $user->name }}</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <textarea>{{ $user->notes }}</textarea>
            </div>
        </div>
    </div>
</div>
      
    @empty
    <p class="text-center">No user Available.</p>
    @endforelse
</div>
@endsection

@section('modal')
    @include('modals.edit-profile')
@endsection


@push('scripts')
    <script>
        function updateRole(userId, role) {
    fetch('{{ route('user.update.role') }}', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-CSRF-TOKEN': '{{ csrf_token() }}',
        },
        body: JSON.stringify({ user_id: userId, role: role }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            // Update the dropdown text dynamically
            document.querySelector(`#roleDropdown-${userId}`).textContent = role;
            alert(data.message);
        } else {
            alert('Failed to update role.');
        }
    })
    .catch(error => console.error('Error:', error));
}

function updateStatus(userId, status) {
    fetch('{{ route('user.update.status') }}', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-CSRF-TOKEN': '{{ csrf_token() }}',
        },
        body: JSON.stringify({ user_id: userId, status: status }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            // Update the dropdown text dynamically
            document.querySelector(`#actionDropdown-${userId}`).textContent = status;
            alert(data.message);
        } else {
            alert('Failed to update status.');
        }
    })
    .catch(error => console.error('Error:', error));
}

    </script>
@endpush()
