<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ViewController;
use App\Http\Controllers\ReviewController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\Auth\OTPController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\CertificateController;
use App\Http\Controllers\CertificateShareController;
use App\Http\Controllers\Auth\RegisteredUserController;

// Splash Screen route
Route::get('/', function () {
    return view('splash.index'); // Splash screen view
});

// Default login page route provided by Breeze
Route::get('/login', function () {
    return view('auth.login'); // Login page
})->name('login');

// Route to send OTP
Route::post('/send-otp', [OtpController::class, 'sendOtp'])->name('otp.send');

// Route to display the OTP verification form (GET request)
Route::get('/verify-otp', [OtpController::class, 'showVerifyForm'])->name('otp.verify.form');

// Route to verify OTP (POST request)
Route::post('/register-user', [RegisteredUserController::class, 'store'])->name('register.complete');

Route::get('/reviews/filter', [ReviewController::class, 'filter'])->name('reviews.filter');

Route::get('/profile/guest/{id}', [ProfileController::class, 'guest'])->name('profile.guest');

// Profile routes (Authenticated users only)
Route::middleware('auth')->group(function () {    
    // Dashboard route (Authenticated users only)
    Route::get('/dashboard',[ViewController::class,'showdashboard'] )->name('dashboard');
    Route::get('/showmycertificates',[ViewController::class,'showmycertificates'] )->name('mycertificates');
    Route::get('/reviews', [ViewController::class, 'showseemyreviews'])->name('seemyreviews');
    Route::get('/certificates/shared', [ViewController::class, 'showsharedcertificates'])->name('sharedcertificates');
    Route::get('/certificates/employeecertificates', [ViewController::class, 'showemployeecertificates'])->name('employeecertificates');
    Route::get('/certificatestoverify', [ViewController::class, 'showcertificatestoverify'])->name('certificates.verify');
    Route::get('/certificatestoverify/search', [ViewController::class, 'searchCertificatestoVerify'])->name('unverified.certificate.search');

    Route::get('/verifiedCertificates', [ViewController::class, 'verifiedCertificates'])->name('verifiedCertificates');
    Route::get('/verifiedCertificates/search', [ViewController::class, 'searchVerifiedCertificates'])->name('verifiedCertificates.search');

    Route::post('/verify-certificate', [ViewController::class, 'verifyCertificate'])->name('certificate.update.status');

    Route::get('/viewgiggycodeusers', [ViewController::class, 'showGiggyCodeUsers'])->name('viewgiggycodeusers');    
    Route::get('/giggycode-users/search', [ViewController::class, 'searchGiggyCodeUsers'])->name('users.search');

    Route::post('/update-role', [ProfileController::class, 'updateRole'])->name('users.updateRole');
    Route::post('/update-status', [ProfileController::class, 'updateStatus'])->name('users.updateStatus');

    Route::post('/user/update-role', [ProfileController::class, 'adminUpdateUserRole'])->name('user.update.role');
    Route::post('/user/update-status', [ProfileController::class, 'adminUpdateUserStatus'])->name('user.update.status');



    Route::get('/profile/edit', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::post('/profile/update', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile/delete', [ProfileController::class, 'destroy'])->name('profile.destroy'); // Delete profile
    
    Route::get('/certificates', [CertificateController::class, 'index'])->name('certificates.index');
    Route::post('/certificates', [CertificateController::class, 'store'])->name('certificates.store');
    Route::delete('/certificates/{certificate}', [CertificateController::class, 'destroy'])->name('certificates.destroy');
    
    Route::resource('certificates', CertificateController::class)->except(['show']);
    // Route::get('certificates/{certificate}/generate-qr', [QrCodeController::class, 'generate'])->name('certificates.generate-qr');

    Route::post('/reviews', [ReviewController::class, 'store'])->name('reviews.store');

    // Authenticated Route
    Route::get('/profile/user/{id}', [ProfileController::class, 'user'])->middleware('auth')->name('profile.user');
    
    // Route to handle rating submission
    Route::post('/users/{user}/rate', [ProfileController::class, 'rate'])->name('users.rate');

    Route::post('/certificates/share', [CertificateShareController::class, 'store'])->name('certificates.share');

    Route::get('/certificates/shared/search', [CertificateController::class, 'search'])->name('certificates.shared.search');
    Route::delete('/certificates/shared/{id}/unshare', [CertificateController::class, 'unshare'])->name('certificates.shared.unshare');

    Route::get('/certificates/employeecertificates/search', [CertificateController::class, 'searchCertificates'])->name('employee-certificates.search');


});

// Logout route
Route::get('/logout', [LoginController::class, 'logout'])->name('logout');

// Ensure the auth routes are loaded
require __DIR__.'/auth.php'; // Breeze authentication routes
